@@ -7,5 +7,8 @@ def object_to_json_response(obj, status=200):
     version of that object
     """
     return JsonResponse(
-        data=obj, status=status, safe=False, json_dumps_params={"ensure_ascii": False},
+        data=obj,
+        status=status,
+        safe=False,
+        json_dumps_params={"ensure_ascii": False},
     )
